@@ -14,16 +14,16 @@ deps="$base/deps"
 inst="$deps/install"
 export deps inst
 
+osmo-clean-workspace.sh
+
 mkdir "$deps" || true
-rm -rf "$inst"
+
+verify_value_string_arrays_are_terminated.py $(find . -name "*.[hc]")
 
 export PKG_CONFIG_PATH="$inst/lib/pkgconfig:$PKG_CONFIG_PATH"
 export LD_LIBRARY_PATH="$inst/lib"
 
 osmo-build-dep.sh libosmocore "" ac_cv_path_DOXYGEN=false
-
-"$deps"/libosmocore/contrib/verify_value_string_arrays_are_terminated.py $(find . -name "*.[hc]")
-
 osmo-build-dep.sh libosmo-abis
 
 set +x
@@ -36,9 +36,11 @@ set -x
 
 cd "$base"
 autoreconf --install --force
-./configure
+./configure --enable-external-tests
 $MAKE $PARALLEL_MAKE
 if [ "x$label" != "xFreeBSD_amd64" ]; then
     $MAKE check || cat-testlogs.sh
     $MAKE distcheck || cat-testlogs.sh
 fi
+
+osmo-clean-workspace.sh
